@@ -3,17 +3,16 @@
 """
 Module implementing MainWindow GUI, anselA
 """
-
 import os
 import sys
 import glob
-import EXIF
+import ui.EXIF
 import math
 import operator
 import webbrowser
-import AnselA_Filters as Filters
-import AnselA_Core as Core
-import AnselA_Graphics as Graphics
+import ui.AnselA_Filters as Filters
+import ui.AnselA_Core as Core
+import ui.AnselA_Graphics as Graphics
 from PIL import Image
 from PIL import ImageDraw
 from PIL import ImageEnhance
@@ -21,7 +20,10 @@ from PyQt4 import QtGui
 from PyQt4 import QtCore 
 from PyQt4.QtGui import QMainWindow
 from PyQt4.QtCore import pyqtSignature
-from Ui_mainWindow import Ui_MainWindow
+from ui.Ui_mainWindow import Ui_MainWindow
+
+
+#from flickcharm import *
 
 
 class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
@@ -41,7 +43,6 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         self.postSetup()
         self.ImageDisplayRefresh(True)
         self.ShowApply(False)
-
     
     def postSetup(self):
         self.tabStrip.setCurrentIndex(0)
@@ -144,9 +145,10 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         elif (self.val.valCurTab == 1):
             self.BWApply(self.val.curIm, self.val.valBW,  True)
         else:
-            self.LevelApply(self.val.curIm,  True)           
+            self.LevelApply(self.val.curIm,  True)
         
         self.ShowApply(False)
+        self.ReturnHistPlots()
     
     @pyqtSignature("Image,String,Bool")
     def BWApply(self, imageToEdit,  cSource,  UpdateRealImage):
@@ -168,26 +170,27 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
             
             
             if cSource == "R":
-                out0=source[R].point(lambda i: i * 3)
-                source[R].paste(out0,  None,  None)
-                out1=source[G].point(lambda i: i * 0)
-                source[G].paste(out1,  None,  None)
-                out2=source[B].point(lambda i: i * 0)
-                source[B].paste(out2,  None,  None)
-                im=Image.merge("RGB", (out0 ,  source[G],  source[B] ))
-                im=im.convert("L")
+#                out0=source[R].point(lambda i: i * 3)
+#                source[R].paste(out0,  None,  None)
+#                out1=source[G].point(lambda i: i * 0)
+#                source[G].paste(out1,  None,  None)
+#                out2=source[B].point(lambda i: i * 0)
+#                source[B].paste(out2,  None,  None)
+#                im=Image.merge("RGB", (out0 ,  source[G],  source[B] ))
+                im = source[R].convert("L")
             elif cSource == "G":
-                out=source[R].point(lambda i: i * 1)
-                source[R].paste(out,  None,  None)
-                out=source[G].point(lambda i: i * 1.9)
-                source[G].paste(out,  None,  None)
-                out=source[B].point(lambda i: i * 1)
-                source[B].paste(out,  None,  None)
-                im=Image.merge("RGB", (source[R] ,  source[G],  source[B] ))
-                im=im.convert("L")
+#                out=source[R].point(lambda i: i * 1)
+#                source[R].paste(out,  None,  None)
+#                out=source[G].point(lambda i: i * 1.9)
+#                source[G].paste(out,  None,  None)
+#                out=source[B].point(lambda i: i * 1)
+#                source[B].paste(out,  None,  None)
+#                im=Image.merge("RGB", (source[R] ,  source[G],  source[B] ))
+#                im=im.convert("L")
+                im = source[G].convert("L")
             elif cSource == "B":
                 #source[B].point(lambda i: i * 1.2)
-                im = source[R].convert("L")
+                im = source[B].convert("L")
             elif cSource == "C":
                 source[B].point(lambda i: i * 1.2)
                 source[G].point(lambda i: i * 1.2)
@@ -329,6 +332,8 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
             self.frameExitRequest.setGeometry(QtCore.QRect(0, 0, 800, 480))
         elif  (index==6):
             self.ReturnHistPlots()
+        elif (index==7):
+            self.PopulateEXIFData(self.val.curImageLoc)
         else:
             self.val.valCurTab = index
         
@@ -341,20 +346,58 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         self.cSlide_Sat.setValue(0)
         self.cSlide_Contrast.setValue(0)
         self.cSlide_Bright.setValue(0)
-    
+        
     @pyqtSignature("")
-    def on_btnLevelApply2_released(self):
+    def TonesApply(self):
         """
         Slot documentation goes here.
         """
         if  (self.val.lockUpdating == False):
             self.showUpdateLabel(True)
             im = self.val.curIm
+            imL = im.convert("")
             enhancer = ImageEnhance.Brightness(im)
             bright_im = enhancer.enhance(self.val.valL*-1*0.01) #any value you want
             self.photo.setPixmap(Core.pil2qpixmap(bright_im))
             self.showUpdateLabel(False)
     
+    
+    @pyqtSignature("")
+    def BrightContrastSatSharpApply(self, imageToEdit,  cSource,  UpdateRealImage):
+        """
+        Slot documentation goes here.
+        """
+        if  (self.val.lockUpdating == False):
+            if (UpdateRealImage == True):
+                self.showUpdateLabel(True,  False)
+            else:
+                self.showUpdateLabel(True,  True)
+                
+            im = imageToEdit
+                
+            if cSource =="Br":
+                enhancer = ImageEnhance.Brightness(im)
+                Eim = enhancer.enhance(self.val.valBr*-1*0.001)
+            if cSource =="Co":
+                enhancer = ImageEnhance.Contrast(im)
+                Eim = enhancer.enhance(self.val.valCo*-1*0.001) 
+            if cSource =="Sa":
+                enhancer = ImageEnhance.Color(im)
+                Eim = enhancer.enhance(self.val.valSa*-1*0.001) 
+            if cSource =="Sh":    
+                enhancer = ImageEnhance.Sharpness(im)
+                Eim = enhancer.enhance(self.val.valSh*-1*0.001) 
+            
+            if (UpdateRealImage == True):
+                self.val.curIm = Eim
+                self.photo.setPixmap(Core.pil2qpixmap(self.val.curIm))
+                self.showUpdateLabel(False,  False)
+            else:
+                self.val.curThumb = Eim
+                self.photo_Thumb.setPixmap(Core.pil2qpixmap(self.val.curThumb))
+                self.showUpdateLabel(False,  True)
+
+    
     @pyqtSignature("")
     def on_btnOpen_released(self):
         """
@@ -366,18 +409,6 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         self.ImageOpen(self.val.curImageLoc)
         self.ImageDisplayRefresh(True)
         
-    @pyqtSignature("Bool")
-    def ImageDisplayRefresh(self,  LoadOriginal) :
-        """
-        Display image on GUI
-        """
-        self.ImageLoad(self.val.curIm,  False)
-        self.photo.setPixmap(Core.pil2qpixmap(self.val.curIm))
-        if LoadOriginal:
-            self.photo_Orig.setPixmap(Core.pil2qpixmap(self.val.curIm))
-        self.photo_Thumb.setPixmap(Core.pil2qpixmap(self.val.curThumb))
-        self.btnFullScreen.setGeometry(self.photo_Thumb.geometry())
-    
     def ImageOpen(self, filename):
         """
         Open File and poulate class parameters of Image.
@@ -385,36 +416,55 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         self.ToggleThumbWait(True)
         self.repaint()
         self.val.curIm= (Image.open(filename))
-
-        p = open(filename, "rb")
-        tags = EXIF.process_file(p)
-        for key in tags.keys():
-            try:
-                newItem = str("%s: %s" %(key, tags[key]))
-                
-                if key == "Image Orientation":
-                    if newItem == "Image Orientation: Horizontal (normal)":
-                        self.val.valOrient = 0
-                    else:
-                        self.val.valOrient = 1
-                    
-                if (newItem !="" and  newItem.startswith("Maker Note") == False  and  newItem.startswith("MakerNote") == False  and  newItem.startswith("EXIF") == False):
-                    self.listEXIFData.addItem(newItem)
-                    #self.listView
-            except Exception, e:
-                continue
-                #print "EXIF Error"
       
         self.val.origIm = self.val.curIm.copy()
         self.ImageLoad(self.val.curIm, True)
-      
+        self.val.EXIFLoaded = False
+    
+    
+    @pyqtSignature("Bool")
+    def ImageDisplayRefresh(self,  LoadOriginal):
+        """
+        Display image on GUI
+        """
+        self.ImageLoad(self.val.curIm,  False)
+        self.photo_Thumb.setPixmap(Core.pil2qpixmap(self.val.curThumb))
+        if LoadOriginal:
+            self.photo_Orig.setPixmap(Core.pil2qpixmap(self.val.curIm))
+        self.photo.setPixmap(Core.pil2qpixmap(self.val.curIm))
+        self.btnFullScreen.setGeometry(self.photo_Thumb.geometry())
+    
+    
+    def PopulateEXIFData(self,  filename):
+        if not self.val.EXIFLoaded:
+            self.val.EXIFLoaded = True
+            self.listEXIFData.clear()
+            p = open(filename, "rb")
+            tags = ui.EXIF.process_file(p)
+            
+            for key in tags.keys():
+                try:
+                    newItem = str("%s: %s" %(key, tags[key]))
+                    
+                    if key == "Image Orientation":
+                        if newItem == "Image Orientation: Horizontal (normal)":
+                            self.val.valOrient = 0
+                        else:
+                            self.val.valOrient = 1
+                        
+                    if (newItem !="" and  newItem.startswith("Maker Note") == False  and  newItem.startswith("MakerNote") == False  and  newItem.startswith("EXIF") == False):
+                        self.listEXIFData.addItem(newItem)
+                        #self.listView
+                except Exception, e:
+                    continue
+                
     def convertImSize(self, origW,  origH,  dConstraint):
         if (self.val.valOrient == 0): #landscape
-            scale=origW/dConstraint
+            scale=origW/(dConstraint*1.0001)
             newW=dConstraint
             newH=int(math.ceil(origH/scale))
         else: # portrait
-            scale=origH/dConstraint
+            scale=origH/(dConstraint*1.0001)
             newH=dConstraint
             newW=int(math.ceil(origW/scale))
             
@@ -426,22 +476,25 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         self.val.curIm = im
         w, h = self.val.curIm.size
         wTh,  hTh = self.convertImSize(w, h,  250)
-        self.photo_Thumb.setGeometry(QtCore.QRect(155-int(wTh/2), 195-int(hTh/2), wTh, hTh))
-
+        
         size = (wTh,  hTh )
         self.val.curThumb = im.resize(size, Image.ANTIALIAS)
-        self.photo_Thumb.repaint()
-        self.ToggleThumbWait(False)
         
+        self.labWaitThumb.setGeometry(QtCore.QRect(155-int(wTh/2), 195-int(hTh/2), wTh, hTh))
+        self.photo_Thumb.setGeometry(QtCore.QRect(155-int(wTh/2), 195-int(hTh/2), wTh, hTh))
+
+
         
         if LoadOriginal:
             wTh,  hTh = self.convertImSize(w, h,  796)
             self.photo_Orig.setGeometry(QtCore.QRect(398-int(wTh/2), 216-int(hTh/2), wTh, hTh))
-            self.photo_Orig.repaint()
+            #self.photo_Orig.repaint()
             
         wTh,  hTh = self.convertImSize(w, h,  796)
         self.photo.setGeometry(QtCore.QRect(398-int(wTh/2), 216-int(hTh/2), wTh, hTh))
-        self.photo.repaint()
+        
+        self.ToggleThumbWait(False)
+        #self.photo.repaint()
 
         #800, 440
         #self.curThumb.thumbnail(size, Image.ANTIALIAS)
@@ -455,93 +508,14 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         Slot documentation goes here.
         """
         if (index == 2):
-            self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 40, 0, 0))
-            self.populatePhotoList()
+            self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 0, 0, 0))
+            if self.val.thumbsCount == 0:
+                self.populatePhotoList()
         else:
-            self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 40, 790, 440))
+            self.btnFullScreenClose.setGeometry(QtCore.QRect(0, 90, 800, 371))
 
 #+++++++++++++++++++++++ END of Class    
-    @pyqtSignature("Bool")
-    def populatePhotoList(self, ForceRefresh=False):
-        """
-        Slot documentation goes here.
-        """
-        if self.val.thumbsCount == 0:
-            self.val.thumbsCount =50
-            
-        self.frameCancelPListLoad.setGeometry(QtCore.QRect(0, 0, 800, 441))
-        self.val.populatePhotoList = True
-        self.listPhotos.clear()
-        
-        self.repaint()
-        self.tabPhoto.repaint()
-        Tsize = (100, 100)
-        i=0
-        self.labCancel.setText("Loading Photos...")
-        if not os.path.exists (self.val.thumbsDir):
-            os.makedirs (self.val.thumbsDir)
-        
-        files =[]
-        for file in os.listdir(self.val.imageDir):
-            files.append(file)
-            
-        for file in reversed(files):
-            if self.val.populatePhotoList ==True:
 
-                if ((not os.path.exists(self.val.thumbsDir+file)) or ForceRefresh):
-                    try:
-                        im = Image.open(self.val.imageDir+file)
-                        im.thumbnail((Tsize), Image.ANTIALIAS)
-                        #os.remove(self.val.thumbsDir+file)
-                        im.save(self.val.thumbsDir+file)
-                    except:
-                        continue
-                    #                    p = open(self.val.imageDir+file, "rb")
-                    #                    tags = EXIF.process_file(p)
-                    #                    Image.open()
-                    #                    tags.get('JPEGThumbnail')
-                
-                try:
-
-                    self.listPhotos.addItem(file.replace(".jpg", ""))
-                    icon = QtGui.QIcon(self.val.thumbsDir+file)
-                    self.listPhotos.item(i).setIcon(icon)
-                    if i % 5 == 0:
-                        self.labCancel.setText("Loading Photos..."+str(i))
-                        self.labCancel.repaint()
-                        self.listPhotos.repaint()
-                except:
-                        continue
-                        
-                i+=1
-                if i == self.val.thumbsCount:
-                    self.listPhotos.addItem("Load More...")
-                    break
-                    
-            self.listPhotos.repaint()
-            self.frameCancelPListLoad.setGeometry(QtCore.QRect(0, 0, 0, 0))
-            #    221
-                
-#         icon2.addPixmap(im,  QtGui.QIcon.Normal, QtGui.QIcon.Off)
-#         icon = QIcon(QPixmap.fromImage(ImageQt.ImageQt(im)))
-#			item = QListWidgetItem(os.path.basename(url)[:20] + "...", self.pictureListWidget)
-#			item.setStatusTip(url)
-#			item.setIcon(icon)
-            
-            
-#            Imitem = QtGui.QListWidgetItem(file.replace(".jpg", "")), self.listPhotos);
-#            Imitem.setIcon(QtGui.QIcon(im))
-#            self.listPhotos.addItem(Imitem)
-
-            
-            #im.save(file + ".thumbnail", "JPEG")
-            #elf.val.curIm = Image.open(filename)
-
-#            p = open(filename, "rb")
-#            tags = EXIF.process_file(p)
-#            self.listEXIFData.addItem
-
-        
     @pyqtSignature("int")
     def on_cSlide_Hi_valueChanged(self, value):
         """
@@ -558,6 +532,14 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         self.val.valMi = value
         self.lcdMi.setText(str(self.val.valMi))
     
+    @pyqtSignature("int")
+    def on_cSlide_Sw_valueChanged(self, value):
+        """
+        Slot documentation goes here.
+        """
+        self.val.valSw = value
+        self.lcdSw.setText(str(self.val.valSw))
+        
     @pyqtSignature("int")
     def on_cSlide_Sh_valueChanged(self, value):
         """
@@ -565,6 +547,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         """
         self.val.valSh = value
         self.lcdSh.setText(str(self.val.valSh))
+        self.BrightContrastSatSharpApply(self.val.curThumb,  "Sh",  False)
     
     @pyqtSignature("int")
     def on_cSlide_Sa_valueChanged(self, value):
@@ -573,14 +556,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         """
         self.val.valSa = value
         self.lcdSa.setText(str(self.val.valSa))
-        
-    @pyqtSignature("int")
-    def on_cSlide_Sw_valueChanged(self, value):
-        """
-        Slot documentation goes here.
-        """
-        self.val.valSw = value
-        self.lcdSw.setText(str(self.val.valSw))
+        self.BrightContrastSatSharpApply(self.val.curThumb,  "Sa",  False)
     
     @pyqtSignature("int")
     def on_cSlide_Co_valueChanged(self, value):
@@ -589,6 +565,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         """
         self.val.valCo = value
         self.lcdCo.setText(str(self.val.valCo))
+        self.BrightContrastSatSharpApply(self.val.curThumb,  "Co",  False)
     
     @pyqtSignature("int")
     def on_cSlide_Br_valueChanged(self, value):
@@ -597,7 +574,8 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         """
         self.val.valBr = value
         self.lcdBr.setText(str(self.val.valBr))
-    
+        self.BrightContrastSatSharpApply(self.val.curThumb,  "Br",  False)
+        
     @pyqtSignature("int")
     def on_dial_valueChanged(self, value):
         """
@@ -608,7 +586,8 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
             self.lcdRot_1.setText(str(self.val.valRot))
             self.RotateThumb(value)
            
-
+    
+    @pyqtSignature("int")
     def RotateThumb(self, rotation):
         self.showUpdateLabel(True,  True)
         im=self.val.curThumb
@@ -621,6 +600,8 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         self.photo_Thumb.setPixmap(Core.pil2qpixmap(im))
         self.showUpdateLabel(False,  True)
         
+    
+    @pyqtSignature("int")    
     def RotateApply(self, rotation):
         if  (self.val.lockUpdating == False):
             self.showUpdateLabel(True,  False)
@@ -632,10 +613,11 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
             self.ImageDisplayRefresh(False)
             self.showUpdateLabel(False,  False)
             self.val.lockUpdating = False
-        
+    
+    @pyqtSignature("int, Image")
     def RotateCalc(self, rotation,  im):
 
-        w,  h = im.size
+        w, h = im.size
         theta =math.radians(rotation)
 
         botOps = round(abs(h * math.sin(theta))/2)
@@ -744,12 +726,12 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         if (Show):
             self.tabPhoto.setCurrentIndex(ForceTab)
             self.framePhoto.setGeometry(QtCore.QRect(0, 0, 800, 480))    
-        else:
-            self.framePhoto.setGeometry(QtCore.QRect(0, 0, 0, 0))
             self.photo.repaint()
             self.photo_Orig.repaint()
+        else:
+            self.framePhoto.setGeometry(QtCore.QRect(0, 0, 0, 0))
             
-        self.tabPhoto.repaint()
+        self.tabPhoto.updateGeometry()
         self.tabStrip.repaint()
         self.repaint()
     
@@ -854,18 +836,9 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     def on_btnBug_released(self):
         """
         Submit bug report to bugs.maemo.org
-        """
- 
+        """ 
         webbrowser.open("https://bugs.maemo.org/enter_bug.cgi?product=AnselA")
-#        self.btnBug.anim=QtCore.QPropertyAnimation(self.btnBug.proxy, "opacity")
-#        self.btnBug.anim.setDuration(200)
-#        self.btnBug.anim.setStartValue(self.btnBug.proxy.opacity())
-#        self.btnBug.anim.setEndValue(target)
-#        self.btnBug.anim.start()
-#        self.btnBug.anim.finished.connect(self.btnBug.anim.deleteLater)
-#    
-#        self.btnBug.anim.finished.connect(self.btnBug)
-    
+
     @pyqtSignature("")
     def on_btnPListCancel_released(self):
         """
@@ -884,41 +857,18 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
     @pyqtSignature("")
     def on_btnPlistZoom_released(self):
         """
-        Slot documentation goes here.
+        This button displays the Zoomed Image, click on it will edit the photo.
         """
         self.LoadCurImageFromPhotoBrowser()
-
+        #self.listPhotos.setCurrentRow(8)
 
     def ToggleThumbWait(self,  Show):
         if Show:
             self.labWaitThumb.setGeometry(QtCore.QRect(30, 120, 251, 161))
-#            self.movie = QtGui.QMovie("ui/resources/wait.png")
-#
-#            self.labWaitThumb.setMovie(self.movie)
-#        
-#            self.movie.setCacheMode(QtGui.QMovie.CacheAll)
-#            self.movie.setSpeed(100) 
-#            self.movie.start()
+
         else:
             self.labWaitThumb.setGeometry(QtCore.QRect(30, 120, 0, 0))
     
-    @pyqtSignature("QListWidgetItem*")
-    def on_listPhotos_itemClicked(self, item):
-        """
-        Slot documentation goes here.
-        """
-        if str(item.text()) == "Load More...":
-            self.val.thumbsCount +=100
-            self.populatePhotoList()
-        else:
-            self.labWait_2.setGeometry(QtCore.QRect(200, 40, 421, 251))
-            self.labWait_2.repaint()
-            self.val.plistIm= self.val.imageDir+str(item.text())+".jpg"
-            im = Image.open(self.val.plistIm)
-            self.photoListZoom.setPixmap(Core.pil2qpixmap(im))
-            self.labWait_2.setGeometry(QtCore.QRect(0, 0, 0, 0))
-            self.labWait_2.repaint()
-    
     @pyqtSignature("")
     def on_butReturn_released(self):
         """
@@ -953,6 +903,7 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         """
         Slot documentation goes here.
         """
+        self.btnEditZoomed.setGeometry(QtCore.QRect(0, 0, 0, 0))
         self.frameReloadRequest.setGeometry(QtCore.QRect(0, 0, 0, 0))
         self.populatePhotoList(True)
     
@@ -962,5 +913,164 @@ class MainWindow(QMainWindow, Ui_MainWindow,  Core.ParamValues):
         Slot documentation goes here.
         """
         self.FullScreenToggle(True,  2)
-        self.populatePhotoList()
+        
+        if self.val.thumbsCount == 0:
+             self.populatePhotoList()
+    
+    @pyqtSignature("")
+    def on_dial_sliderReleased(self):
+        """
+        Slot documentation goes here.
+        """
+        # TODO: not implemented yet
+        raise NotImplementedError
+    
+    @pyqtSignature("QListWidgetItem*")
+    def on_listPhotos_itemPressed(self, item):
+        """
+        Slot documentation goes here.
+        """
+        self.setZoomPhoto(item)
+        #self.photoListZoom.setPixmap(item.icon().pixmap(item.getIconSize()[0],item.getIconSize()[1]))
+
+    @pyqtSignature("Bool")
+    def populatePhotoList(self, ForceRefresh=False):
+        """
+        Slot documentation goes here.
+        """
+
+        if self.val.thumbsCount == 0:
+            self.val.thumbsCount =51
+            
+        self.frameCancelPListLoad.setGeometry(QtCore.QRect(0, 0, 800, 441))
+        self.val.populatePhotoList = True
+        self.listPhotos.clear()
+        
+        self.repaint()
+        self.tabPhoto.repaint()
+        Tsize = (100,  100)
+        i=0
+        self.labCancel.setText("Loading Photos...")
+        self.labCancel.repaint()
+        if not os.path.exists (self.val.thumbsDir):
+            os.makedirs (self.val.thumbsDir)
+        
+        files =[]
+        for file in os.listdir(self.val.imageDir):
+            files.append(file)
+            
+        for file in reversed(files):
+            if self.val.populatePhotoList ==True:
+
+                if ((not os.path.exists(self.val.thumbsDir+file)) or ForceRefresh):
+                    try:
+                        im = Image.open(self.val.imageDir+file)
+                        im.thumbnail((Tsize), Image.NEAREST)
+                        #os.remove(self.val.thumbsDir+file)
+                        im.save(self.val.thumbsDir+file)
+                    except:
+                        continue
+                
+                try:
+                    photoItem = PlistWidgetItem()
+                    im=Image.open(self.val.thumbsDir+file,  "r" )
+                    icon =QtGui.QIcon(self.val.thumbsDir+file)
+                    photoItem.setIcon(icon)
+                    photoItem.setText(file.replace(".jpg", ""))
+                    photoItem.setIconSize(im.size[0], im.size[1])
+                    photoItem.setImageLocation(self.val.thumbsDir+file)
+                    photoItem.setImageLocation(self.val.curImageLoc+file)
+                    h, w = self.convertImSize(im.size[0], im.size[1],  400)
+                    photoItem.setIconZoomSize(self.ScaleLabel(220,  380, w,  h))
+                    self.listPhotos.addItem(photoItem)
+                    self.listPhotos.item(i).setIcon(icon)
+                    if i % 5 == 0:
+                        self.labCancel.setText("Loading Photos..."+str(i))
+                        self.labCancel.repaint()
+                except:
+                        continue
+                        
+                i+=1
+                if i == self.val.thumbsCount:
+                    self.listPhotos.addItem("Load More...")
+                    break
+                    
+        self.listPhotos.repaint()
+        self.frameCancelPListLoad.setGeometry(QtCore.QRect(0, 0, 0, 0))
+
+
+    @pyqtSignature("QListWidgetItem*")
+    def on_listPhotos_itemClicked(self, item):
+        """
+        Slot documentation goes here.
+        """
+        if str(item.text()) == "Load More...":
+            self.val.thumbsCount +=100
+            self.populatePhotoList()
+            self.btnEditZoomed.setGeometry(QtCore.QRect(220, 280, 281, 0))
+        else:
+            #self.photoListZoom.setPixmap(item.icon().pixmap(item.getIconZoomSize().height(),  item.getIconZoomSize().width()))
+            self.photoListZoom.setGeometry(item.getIconZoomSize())
+            self.btnPlistZoom.setGeometry(self.photoListZoom.geometry())
+            self.val.plistIm= self.val.imageDir+str(item.text())+".jpg"
+            im = Image.open(self.val.plistIm)
+            wTh,  hTh = self.convertImSize(im.size[0], im.size[1],  400)
+            
+            plistTim=im.resize((hTh,  wTh))
+            self.photoListZoom.setPixmap(Core.pil2qpixmap(plistTim))
+            self.photoListZoom.repaint()
+            #self.photoListZoom.setGeometry(self.ScaleLabel(220,  340, hTh,  wTh))
+            
+    @pyqtSignature("QListWidgetItem*")
+    def setZoomPhoto(self, item):
+        """
+        Slot documentation goes here.
+        """
+#        w, h=item.getIconSize()
+#        self.photoListZoom.setGeometry(self.ScaleLabel(220,  340, h, w ))
+#        self.photoListZoom.setPixmap(item.icon().pixmap(h,  w))
+
+    @pyqtSignature("int, int, int, int")
+    def ScaleLabel(self, yH, xW, h, w):
+        """
+        Send widget x(Width), y(Height) of center point
+        and h,w of image passed.
+        """
+        return QtCore.QRect(xW-int(w/2), yH-int(h/2), w, h)
+
+
+class PlistWidgetItem(QtGui.QListWidgetItem):
+    iconSize =(0, 0)
+    iconZoomSize =(0, 0, 0, 0)
+    thumbLocation= ""
+    imageLocation =""
+    
+    def setIconSize(self,  Height=0,  Width=0):
+        self.iconSize =(Height,  Width)
+
+    def getIconSize(self):
+        return self.iconSize
+
+    def setIconZoomSize(self, value):
+        self.iconZoomSize = value
+        
+    def getIconZoomSize(self):
+        return self.iconZoomSize
+        
+    def getImageLocation(self):
+        return self.imageLocation
+
+    def setImageLocation(self, value):
+        self.imageLocation = value
+
+    def getThumbLocation(self):
+        return self.thumbLocation
+
+    def setThumbLocation(self, value):
+        self.thumbLocation = value
+    
+    
+    
+    
+    
     
